"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable key-spacing */
/* eslint-disable @typescript-eslint/no-unused-vars */
const command_1 = require("@oclif/command");
const templates_1 = require("../templates");
const _ = require('lodash');
const path = require('path');
const defaults = require('./../../config/settings.json');
const { Form, Select, Editable } = require('clipprs-enquirer');
/// DATABASE ///
// initialize db
const low = require('lowdb');
const FileSync = require('lowdb/adapters/FileSync');
const adapter = new FileSync(path.join(defaults.db.path, defaults.db.filename));
const db = low(adapter);
// setup defaults //
db.defaults(defaults.db.defaults)
    .write();
/// \DATABASE ///
// dynamically generate prompt from template
const newPersonPrompt = new Editable({
    name: 'new-entry',
    message: 'Add a person to your Clips.\n [ctrl+n] to add fields,\n [ctrl+r] to remove.\n The default fields are required.\n',
    choices: () => {
        const prompt_choices = [];
        for (const key of Object.keys(templates_1.DEFAULT_TEMPLATE_PERSON)) {
            const promptTemplate = _.cloneDeep(templates_1.PROMPT_TEMPLATE);
            promptTemplate.name = key;
            promptTemplate.message = key;
            promptTemplate.required = defaults.requiredFields.includes(key);
            prompt_choices.push(promptTemplate);
        }
        // prompt_choices.push(BLANK_INPUT_TEMPLATE)
        return prompt_choices;
    },
    result(value) {
        // trim excess spaces from object values
        return _.mapValues(value, (val) => val.trim());
    },
    validate: (answer) => {
        // check that field is not blank
        if (Object.values(answer).map(s => s.trim()).includes('')) {
            return 'Error. Blank fields are not allowed.';
        }
        return true;
    },
});
class New extends command_1.Command {
    async run() {
        this.log(`${defaults.startupMessage} | ${defaults.version}`);
        newPersonPrompt.run()
            .then((newPersonObject) => {
            db.get('people')
                .push(newPersonObject)
                .write();
            db.update('count', (n) => n + 1)
                .write();
        })
            .catch(console.error);
    }
}
exports.default = New;
New.description = 'Clip a new person into your system';
New.flags = {
    help: command_1.flags.help({ char: 'h' }),
};
